@@ -13,3 +13,6 @@ TEST_INELS_MQTT_CLASS_NAMESPACE = "inelsmqtt.InelsMqtt"
 TEST_TOPIC_STATE = "inels/status/4254524524/02/452454"
 TEST_TOPIC_SET = "inels/set/4254524524/02/452454"
 TEST_TOPIC_CONNECTED = "inels/connected/4254524524/02/452454"
+
+TEST_SWITCH_AVAILABILITY_ON = "on\n"
+TEST_SWITCH_AVAILABILITY_OFF = "off\n"
